==> green-core-1.70.1.tgz: package/components/badge/badge.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _renderLeadSlot, renderLeadSlot_fn, _renderMainSlot, renderMainSlot_fn, _handleSlotChange, handleSlotChange_fn, _renderTrailSlot, renderTrailSlot_fn;
import { property, state } from "lit/decorators.js";
import { GdsElement } from "../../gds-element";
import { html } from "../../scoping";
import { tokens } from "../../tokens.style";
import { gdsCustomElement } from "../../utils/helpers/custom-element-scoping";
import {
  withLayoutChildProps,
  withMarginProps,
  withSizeXProps
} from "../../utils/mixins/declarative-layout-mixins";
import { GdsFlex } from "../flex/flex.component";
import BadgeCSS from "./badge.style";
let GdsBadge = class extends withSizeXProps(
  withMarginProps(withLayoutChildProps(GdsElement))
) {
  constructor() {
    super(...arguments);
    __privateAdd(this, _renderLeadSlot);
    __privateAdd(this, _renderMainSlot);
    __privateAdd(this, _handleSlotChange);
    __privateAdd(this, _renderTrailSlot);
    this.variant = "information";
    this.size = "default";
    this.disabled = false;
    this.notification = false;
    this.rounded = false;
    this.mainSlotOccupied = false;
  }
  render() {
    const background = this.disabled ? "disabled" : this.notification ? this.variant : this.variant + "-badge";
    const color = this.disabled ? "disabled" : this.notification ? "primary" : this.variant;
    const padding = this.size === "small" || this.notification ? "2xs" : "xs";
    const blockSize = this.mainSlotOccupied ? this.size === "small" || this.notification ? "m" : "l" : "xs";
    return html`<gds-flex
      level="3"
      background=${background}
      color=${color}
      gap="${this.notification ? "" : "2xs"}"
      align-items="center"
      justify-content="flex-start"
      padding-inline="${padding}"
      border-radius="${this.notification || this.rounded ? "max" : "2xs"}"
      block-size="${blockSize}"
      width="100%"
      font-size="${this.size === "small" || this.notification ? "detail-xs" : "detail-s"}"
      pointer-events=${this.disabled ? "none" : "auto"}
      user-select="${this.disabled ? "none" : "auto"}"
    >
      ${__privateMethod(this, _renderLeadSlot, renderLeadSlot_fn).call(this)} ${__privateMethod(this, _renderMainSlot, renderMainSlot_fn).call(this)}
      ${__privateMethod(this, _renderTrailSlot, renderTrailSlot_fn).call(this)}
    </gds-flex>`;
  }
};
_renderLeadSlot = new WeakSet();
renderLeadSlot_fn = function() {
  if (this.size !== "small" || !this.notification) {
    return html`<slot name="lead"></slot>`;
  }
};
_renderMainSlot = new WeakSet();
renderMainSlot_fn = function() {
  return html`<slot @slotchange=${__privateMethod(this, _handleSlotChange, handleSlotChange_fn)}></slot>`;
};
_handleSlotChange = new WeakSet();
handleSlotChange_fn = function(event) {
  const slot = event.target;
  const assignedNodes = slot.assignedNodes({ flatten: true });
  this.mainSlotOccupied = assignedNodes.length > 0 && assignedNodes.some(
    (node) => node.nodeType === Node.ELEMENT_NODE || node.nodeType === Node.TEXT_NODE && node.textContent?.trim() !== ""
  );
};
_renderTrailSlot = new WeakSet();
renderTrailSlot_fn = function() {
  return html`<slot name="trail"></slot>`;
};
GdsBadge.styles = [tokens, BadgeCSS];
__decorateClass([
  property()
], GdsBadge.prototype, "variant", 2);
__decorateClass([
  property({ type: String })
], GdsBadge.prototype, "size", 2);
__decorateClass([
  property({
    attribute: "disabled",
    type: Boolean,
    reflect: true
  })
], GdsBadge.prototype, "disabled", 2);
__decorateClass([
  property({
    attribute: "notification",
    type: Boolean,
    reflect: true
  })
], GdsBadge.prototype, "notification", 2);
__decorateClass([
  property({
    attribute: "rounded",
    type: Boolean,
    reflect: true
  })
], GdsBadge.prototype, "rounded", 2);
__decorateClass([
  state()
], GdsBadge.prototype, "mainSlotOccupied", 2);
GdsBadge = __decorateClass([
  gdsCustomElement("gds-badge", { dependsOn: [GdsFlex] })
], GdsBadge);
export {
  GdsBadge
};

==> green-core-1.71.0.tgz: package/components/badge/badge.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _renderLeadSlot, renderLeadSlot_fn, _renderMainSlot, renderMainSlot_fn, _handleSlotChange, handleSlotChange_fn, _renderTrailSlot, renderTrailSlot_fn;
import { property, state } from "lit/decorators.js";
import { GdsElement } from "../../gds-element.js";
import { html } from "../../scoping.js";
import { tokens } from "../../tokens.style";
import { gdsCustomElement } from "../../utils/helpers/custom-element-scoping.js";
import {
  withLayoutChildProps,
  withMarginProps,
  withSizeXProps
} from "../../utils/mixins/declarative-layout-mixins.js";
import { GdsFlex } from "../flex/flex.component.js";
import BadgeCSS from "./badge.style";
let GdsBadge = class extends withSizeXProps(
  withMarginProps(withLayoutChildProps(GdsElement))
) {
  constructor() {
    super(...arguments);
    __privateAdd(this, _renderLeadSlot);
    __privateAdd(this, _renderMainSlot);
    __privateAdd(this, _handleSlotChange);
    __privateAdd(this, _renderTrailSlot);
    this.variant = "information";
    this.size = "default";
    this.disabled = false;
    this.notification = false;
    this.rounded = false;
    this.mainSlotOccupied = false;
  }
  render() {
    const background = this.disabled ? "disabled" : this.notification ? this.variant : this.variant + "-badge";
    const color = this.disabled ? "disabled" : this.notification ? "primary" : this.variant;
    const padding = this.size === "small" || this.notification ? "2xs" : "xs";
    const blockSize = this.mainSlotOccupied ? this.size === "small" || this.notification ? "m" : "l" : "xs";
    return html`<gds-flex
      level="3"
      background=${background}
      color=${color}
      gap="${this.notification ? "" : "2xs"}"
      align-items="center"
      justify-content="flex-start"
      padding-inline="${padding}"
      border-radius="${this.notification || this.rounded ? "max" : "2xs"}"
      block-size="${blockSize}"
      width="100%"
      font-size="${this.size === "small" || this.notification ? "detail-xs" : "detail-s"}"
      pointer-events=${this.disabled ? "none" : "auto"}
      user-select="${this.disabled ? "none" : "auto"}"
    >
      ${__privateMethod(this, _renderLeadSlot, renderLeadSlot_fn).call(this)} ${__privateMethod(this, _renderMainSlot, renderMainSlot_fn).call(this)}
      ${__privateMethod(this, _renderTrailSlot, renderTrailSlot_fn).call(this)}
    </gds-flex>`;
  }
};
_renderLeadSlot = new WeakSet();
renderLeadSlot_fn = function() {
  if (this.size !== "small" || !this.notification) {
    return html`<slot name="lead"></slot>`;
  }
};
_renderMainSlot = new WeakSet();
renderMainSlot_fn = function() {
  return html`<slot @slotchange=${__privateMethod(this, _handleSlotChange, handleSlotChange_fn)}></slot>`;
};
_handleSlotChange = new WeakSet();
handleSlotChange_fn = function(event) {
  const slot = event.target;
  const assignedNodes = slot.assignedNodes({ flatten: true });
  this.mainSlotOccupied = assignedNodes.length > 0 && assignedNodes.some(
    (node) => node.nodeType === Node.ELEMENT_NODE || node.nodeType === Node.TEXT_NODE && node.textContent?.trim() !== ""
  );
};
_renderTrailSlot = new WeakSet();
renderTrailSlot_fn = function() {
  return html`<slot name="trail"></slot>`;
};
GdsBadge.styles = [tokens, BadgeCSS];
__decorateClass([
  property()
], GdsBadge.prototype, "variant", 2);
__decorateClass([
  property({ type: String })
], GdsBadge.prototype, "size", 2);
__decorateClass([
  property({
    attribute: "disabled",
    type: Boolean,
    reflect: true
  })
], GdsBadge.prototype, "disabled", 2);
__decorateClass([
  property({
    attribute: "notification",
    type: Boolean,
    reflect: true
  })
], GdsBadge.prototype, "notification", 2);
__decorateClass([
  property({
    attribute: "rounded",
    type: Boolean,
    reflect: true
  })
], GdsBadge.prototype, "rounded", 2);
__decorateClass([
  state()
], GdsBadge.prototype, "mainSlotOccupied", 2);
GdsBadge = __decorateClass([
  gdsCustomElement("gds-badge", { dependsOn: [GdsFlex] })
], GdsBadge);
export {
  GdsBadge
};
